@@ -443,7 +443,7 @@ def local_subtensor_lift(fgraph, node):
             # i indexes broadcastable pattern before subtensor
             # j indexes broadcastable pattern after subtensor
             j = 0
-            for (i, x) in enumerate(node.op.idx_list):
+            for i, x in enumerate(node.op.idx_list):
                 # if it is not a slice, it will reduce the dimension, should
                 # not appear in the broascastable dimensions
                 if isinstance(x, slice):
@@ -819,7 +819,6 @@ def local_useless_inc_subtensor(fgraph, node):
         )
         for e in idx_cst
     ):
-
         # `IncSubtensor` broadcasts `x` on `y` based on run-time shapes, so we
         # must check that they are the same
         if not fgraph.shape_feature.same_shape(x, y):
@@ -1375,7 +1374,6 @@ def local_setsubtensor_of_constants(fgraph, node):
             return
 
         if replace_x == replace_y:
-
             # No need to copy over the stacktrace,
             # because x should already have a stacktrace
             return [x]
@@ -1733,7 +1731,6 @@ def local_join_subtensors(fgraph, node):
             )
             if i != axis
         ):
-
             base_tensor = subtensor1.owner.inputs[0]
             new_idxs = list(idxs_subtensor1)
             new_idxs[axis] = slice(start_subtensor1, stop_subtensor2, step_subtensor1)
@@ -1775,7 +1772,6 @@ def local_uint_constant_indices(fgraph, node):
     has_new_index = False
 
     for i, index in enumerate(new_indices):
-
         if not isinstance(index, Constant):
             continue
 
